@@ -195,26 +195,3 @@ class CompareDeviceConfCommandTests(HelperTest):
         self.assertEqual(output.getvalue(),
                          "Success. The configuration files are identical.\n")
         sys.stdout = sys.__stdout__
-
-    @unittest.skipIf(not os.path.exists('/etc/lava-server/dispatcher-config/device-types/qemu.yaml'), 'lava-server not configured')
-    def test_command_invoke_3(self):
-        # Test when configuration files are different.
-        sys.stdout = output = StringIO()
-        self.args.CONFIGS = ["lava/tests/qemu01.example.yaml",
-                             "lava/tests/qemu02.example.yaml"]
-        compare_command = compare_device_conf(self.parser, self.args)
-
-        result = compare_command.invoke()
-        self.assertEqual(result, 0)
-        self.assertEqual(output.getvalue(),
-                         "[--- lava/tests/qemu01.example.yaml-]\n" +
-                         "{+++ lava/tests/qemu02.example.yaml+}\n\n" +
-                         "@@ -18,8 +18,8 @@\n\n          " +
-                         "- -nographic\n          " +
-                         "- -enable-kvm\n          " +
-                         "- -cpu host\n          " +
-                         "- -net [-nic,model=virtio,macaddr=52:54:00:12:34:58-] {+nic,model=virtio,macaddr=15:54:00:12:34:43+} " +
-                         "-net user\n          " +
-                         "- -m [-512-] {+1024+}\n\ntest_image_prompts:\n  " +
-                         "- '(initramfs)'\n")
-        sys.stdout = sys.__stdout__
