@@ -21,6 +21,7 @@
 import argparse
 import difflib
 import jinja2
+import json
 import os
 import re
 import sys
@@ -50,7 +51,6 @@ from lava_scheduler_tool.scheduler import (
 if sys.version_info < (3, 0):
     import urlparse
     import xmlrpclib
-    from lava_dashboard_tool.commands import _get_pretty_renderer
 # Enable only once python3 support is ready, then switch over.
 # else:
 #    import urllib.parse  # pylint: disable=import-error,unused-import,no-name-in-module
@@ -163,7 +163,7 @@ class submit_job(Command):  # pylint: disable=invalid-name
 
         if self.args.block:
             print('')
-            print('This kind of polling is deprecated and will be removed in the next release. Please use "wait-for-job" command.')
+            print('This kind of polling is deprecated and will be removed in the next release. Please use "wait-job-events" command.')
             print('')
             print('Waiting for the job to run ')
             print('. = job waiting in the queue')
@@ -329,19 +329,6 @@ class jobs_list(Command):  # pylint: disable=invalid-name
     """
     Get list of running and submitted jobs from the scheduler.
     """
-    renderer = _get_pretty_renderer(
-        order=('id', 'description', 'status', 'actual_device', 'requested_device'),
-        column_map={
-            'id': 'Job ID',
-            'description': 'Job description',
-            'status': 'Job status',
-            'actual_device': 'Device',
-            'requested_device': 'Requested device or device type'},
-        row_formatter={
-            'actual_device': lambda x: x or "",
-            'requested_device': lambda x: x or ""},
-        empty="There are no running or submitted jobs",
-        caption="Jobs list")
 
     def reparse_arguments(self, parser, raw_args):
         pass
@@ -359,26 +346,7 @@ class jobs_list(Command):  # pylint: disable=invalid-name
         except xmlrpclib.Fault as exc:
             raise CommandError(str(exc))
 
-        data_for_renderer = []
-        for row in ret_list:
-            if row[6]:
-                job_id = row[6]
-            else:
-                job_id = row[0]
-            if row[4]:
-                req_d = row[4]["hostname"]
-            else:
-                req_d = row[5]["name"]
-            if row[3]:
-                req_d = ""
-                act_d = row[3]["hostname"]
-            else:
-                act_d = ""
-            data_for_renderer.append(
-                dict(zip(['id', 'description', 'status', 'actual_device', 'requested_device'],
-                         [job_id, row[1], row[2], act_d, req_d])))
-
-        self.renderer.render(data_for_renderer)
+        print(json.dumps(ret_list))
 
 
 class devices_list(Command):  # pylint: disable=invalid-name
@@ -386,18 +354,6 @@ class devices_list(Command):  # pylint: disable=invalid-name
     Get list of devices from the scheduler.
     """
 
-    renderer = _get_pretty_renderer(
-        order=('hostname', 'device_type_name', 'status', 'job'),
-        column_map={
-            'hostname': 'Hostname',
-            'device_type_name': 'Device type',
-            'status': 'Status',
-            'job': 'Job ID'},
-        row_formatter={
-            'job': lambda x: x or ""},
-        empty="There are no devices",
-        caption="Devices list")
-
     def reparse_arguments(self, parser, raw_args):
         pass
 
@@ -411,17 +367,7 @@ class devices_list(Command):  # pylint: disable=invalid-name
             self.args.SERVER, auth_backend=KeyringAuthBackend())
         all_devices = server.scheduler.all_devices()
 
-        data_for_renderer = []
-        for row in all_devices:
-            if row[3]:
-                job_id = row[3]
-            else:
-                job_id = ""
-            data_for_renderer.append(
-                dict(zip(['hostname', 'device_type_name', 'status', 'job'],
-                         [row[0], row[1], row[2], job_id])))
-
-        self.renderer.render(data_for_renderer)
+        print(all_devices)
 
 
 class get_pipeline_device_config(Command):  # pylint: disable=invalid-name
@@ -696,8 +642,10 @@ class wait_job_events(Command):  # pylint: disable=invalid-name
     Wait for job to finish and return job details.
     """
 
-    FINISHED_JOB_STATE = "Finished"
+    FINISHED_JOB_STATE = ["Finished"]
+    FINISHED_JOB_STATUS = ["Complete", "Incomplete", "Canceled"]
     EVENT_SOCKET_PATTERN_SYMBOL = "*"
+    API_UPDATE_VERSION = "2018.1"
 
     def reparse_arguments(self, parser, raw_args):
         pass
@@ -742,12 +690,20 @@ class wait_job_events(Command):  # pylint: disable=invalid-name
         host = get_server_url(auth_backend, self.args.SERVER)
         hostname = urlparse.urlparse(host).hostname
 
+        # Support both old and new API versions.
+        if server.system.version().split("+")[0] >= self.API_UPDATE_VERSION:
+            state_key = "state"
+            relevant_finished_states = self.FINISHED_JOB_STATE
+        else:
+            state_key = "status"
+            relevant_finished_states = self.FINISHED_JOB_STATUS
+
         if self.args.job_id:
             job_ids = [self.args.job_id]
             try:
                 job = server.scheduler.job_details(self.args.job_id)
 
-                if job["state"] == self.FINISHED_JOB_STATE:
+                if job[state_key] in relevant_finished_states:
                     print("Job %s already finished with state %s." % (
                         self.args.job_id, job["health"]))
                     return
@@ -817,7 +773,7 @@ class wait_job_events(Command):  # pylint: disable=invalid-name
                             if data["job"] in job_ids:
                                 data["job"] = urlparse.urljoin(
                                     job_url_template, str(data["job"]))
-                                if data["state"] == self.FINISHED_JOB_STATE:
+                                if data[state_key] in relevant_finished_states:
                                     print(data)
                                     break
                                 elif not self.args.quiet:
